# How to build the documentation

Run the following command from the `docs` folder of the project:

```bash
make html
```

## Visualize the website

You can open the `_build/index.html` file in your browser.
